@@ -51,19 +51,38 @@ static int evdi_get_modes(struct drm_connector *connector)
 #endif
 
 	if (ret) {
-		EVDI_ERROR("Failed to set edid property! error: %d", ret);
+		EVDI_ERROR("Failed to set edid property! error: %d\n", ret);
 		goto err;
 	}
 
 	ret = drm_add_edid_modes(connector, edid);
-	EVDI_INFO("(card%d) Edid property set", evdi->dev_index);
+	EVDI_INFO("(card%d) Edid property set\n", evdi->dev_index);
 err:
 	kfree(edid);
 	return ret;
 }
 
+static bool is_lowest_frequency_mode_of_given_resolution(
+	struct drm_connector *connector, const struct drm_display_mode *mode)
+{
+	struct drm_display_mode *modeptr;
+
+	list_for_each_entry(modeptr, &(connector->modes), head) {
+		if (modeptr->hdisplay == mode->hdisplay &&
+			modeptr->vdisplay == mode->vdisplay &&
+			drm_mode_vrefresh(modeptr) < drm_mode_vrefresh(mode)) {
+			return false;
+		}
+	}
+	return true;
+}
+
 static enum drm_mode_status evdi_mode_valid(struct drm_connector *connector,
+#if KERNEL_VERSION(6, 15, 0) <= LINUX_VERSION_CODE
+					    const struct drm_display_mode *mode)
+#else
 					    struct drm_display_mode *mode)
+#endif
 {
 	struct evdi_device *evdi = connector->dev->dev_private;
 	uint32_t area_limit = mode->hdisplay * mode->vdisplay;
@@ -72,9 +91,9 @@ static enum drm_mode_status evdi_mode_valid(struct drm_connector *connector,
 	if (evdi->pixel_per_second_limit == 0)
 		return MODE_OK;
 
-	if (area_limit > evdi->pixel_area_limit ||
-	    mode_limit > evdi->pixel_per_second_limit) {
-		EVDI_WARN("(card%d) Mode %dx%d@%d rejected\n",
+	if (area_limit > evdi->pixel_area_limit) {
+		EVDI_WARN(
+			"(card%d) Mode %dx%d@%d rejected. Reason: mode area too big\n",
 			evdi->dev_index,
 			mode->hdisplay,
 			mode->vdisplay,
@@ -82,7 +101,27 @@ static enum drm_mode_status evdi_mode_valid(struct drm_connector *connector,
 		return MODE_BAD;
 	}
 
-	return MODE_OK;
+	if (mode_limit <= evdi->pixel_per_second_limit)
+		return MODE_OK;
+
+	if (is_lowest_frequency_mode_of_given_resolution(connector, mode)) {
+		EVDI_WARN(
+			"(card%d) Mode exceeds maximal frame rate for the device. Mode %dx%d@%d may have a limited output frame rate",
+			evdi->dev_index,
+			mode->hdisplay,
+			mode->vdisplay,
+			drm_mode_vrefresh(mode));
+		return MODE_OK;
+	}
+
+	EVDI_WARN(
+		"(card%d) Mode %dx%d@%d rejected. Reason: mode pixel clock too high\n",
+		evdi->dev_index,
+		mode->hdisplay,
+		mode->vdisplay,
+		drm_mode_vrefresh(mode));
+
+	return MODE_BAD;
 }
 
 static enum drm_connector_status
