@@ -20,16 +20,21 @@
 #ifndef _EVDI_PLATFORM_DRV_H_
 #define _EVDI_PLATFORM_DRV_H_
 
+#include <linux/version.h>
+
 struct device;
 struct platform_device_info;
 
 #define DRIVER_NAME   "evdi"
 #define DRIVER_DESC   "Extensible Virtual Display Interface"
-#define DRIVER_DATE   "20240814"
+#if KERNEL_VERSION(6, 14, 0) <= LINUX_VERSION_CODE
+#else
+#define DRIVER_DATE   "20250508"
+#endif
 
 #define DRIVER_MAJOR 1
 #define DRIVER_MINOR 14
-#define DRIVER_PATCH 6
+#define DRIVER_PATCH 10
 
 void evdi_platform_remove_all_devices(struct device *device);
 unsigned int evdi_platform_device_count(struct device *device);
